import es
import playerlib
import vecmath
import gamethread
from JoeyCMDs import JoeyCMDs

est = JoeyCMDs("est")

thermal_players = set() 

#######################################
#SERVER VARIABLES

use_overlay = es.ServerVar("use_overlay", "effects/combine_binocoverlay.vmt", "What overlay should be used?")
see_thru_walls_sprite = es.ServerVar("see_thru_walls_sprite", "effects/strider_bulge_dudv_dx60.vmt", "Special seen thru walls sprites")
refresh_rate = es.ServerVar("refresh_rate", 0.1, "Sprite refresh rate")

'''
sprites/lgtning_noz.vmt
sprites/physcannon_bluecore1b.vmt
sprites/crosshairs.vmt 
sprites/640hud9.vmt 
effects/strider_bulge_dudv_dx60.vmt
'''

#######################################
# ADDON INFORMATION
info = es.AddonInfo()
info.name           = "Thermal goggles"
info.version        = "1.0"
info.author         = "Juba_PornBorn"
info.url            = "http://addons.eventscripts.com/addons/view/"
info.description    = "Gives thermal vision goggles to users"

#######################################

def load():
    es.ServerVar("thermal_vision", info.version).makepublic()
    
    es.regclientcmd('!thermal', 'thermal/start', "Start thermal vision")
    
    es.dbgmsg(0,"[Thermal goggles] Loaded")

def es_map_start(event_var): 
    thermal_players.clear() 

def start(): 
    userid = es.getcmduserid() 
    player = playerlib.getPlayer(userid) 
    if userid in thermal_players: 
        thermal_players.remove(userid) 
        if not thermal_players: 
            gamethread.cancelDelayed('thermal_loop') 

        es.emitsound('player', userid, "weapons/zoom.wav", 0.7, 0.5) 
        es.cexec(userid, "r_screenoverlay 0") 

    else: 
        if playerlib.getPlayer(userid).get('isdead'): 
            es.tell(userid, 'You cannot use that command while dead') 

        else: 
            es.emitsound('player', userid, "ambient/office/button1.wav", 0.7, 0.5) 
            es.cexec(userid, "r_screenoverlay %s"%use_overlay) 

            if not thermal_players: # Start the loop if this is the first player 
                gamethread.delayedname(refresh_rate, 'thermal_loop', loopers)
            
            thermal_players.add(userid) 

def loopers():
    for userid in thermal_players:
        for user in filter(lambda x:not x == userid and not es.getplayerprop(x, 'CBasePlayer.pl.deadflag'), es.getUseridList()):
            x, y, z = es.getplayerlocation(user)
            userv = vecmath.vector(es.getplayerlocation(user))
            useridv = vecmath.vector(es.getplayerlocation(userid))
            distance = vecmath.distance(userv, useridv)
            alpha = 255 - (distance - 1) / 4
            if alpha > 255:
                alpha = 255
            elif alpha < 0:
                alpha = 0
            #es.msg('alpha: %s distance: %s'%(alpha, distance))        
            #<x> <y> <z> <start radius> <end radius> <life> <width> <spread> <amplitude> <Red> <Green> <Blue> <Alpha> <speed> 
            #es.server.queuecmd('est_effect 10 %s 0 %s %s %s %s 30 50 0.1 50 0 0 255 100 100 255 0' % (userid, see_thru_walls_sprite, x, y, z + 50)) 
            est.effect(11, userid, 0,see_thru_walls_sprite, x, y, z + 20, refresh_rate, 1, "%i"%alpha)
    gamethread.delayedname(refresh_rate, 'thermal_loop', loopers) 

def unload():
    es.dbgmsg(0,"[Thermal goggles] Unloaded")
    gamethread.cancelDelayed('thermal_loop')